@@ -1,6 +1,6 @@
 package Modern::Perl;
 # ABSTRACT: enable all of the features of Modern Perl with one import
-$Modern::Perl::VERSION = '1.20161229';
+$Modern::Perl::VERSION = '1.20170115';
 use 5.010_000;
 
 use strict;
@@ -18,11 +18,11 @@ sub VERSION
 {
     my ($self, $version) = @_;
 
-    return $Modern::Perl::VERSION || 2016 unless defined $version;
-    return $Modern::Perl::VERSION || 2016 if             $version < 2009;
+    return $Modern::Perl::VERSION || 2017 unless defined $version;
+    return $Modern::Perl::VERSION || 2017 if             $version < 2009;
 
     $wanted_date = $version if (caller(1))[3] =~ /::BEGIN/;
-    return 2016;
+    return 2017;
 }
 
 sub import
@@ -56,6 +56,7 @@ my %dates =
     2014 => ':5.18',
     2015 => ':5.20',
     2016 => ':5.24',
+    2017 => ':5.24',
 );
 
 sub validate_date
@@ -90,7 +91,7 @@ Modern::Perl - enable all of the features of Modern Perl with one import
 
 =head1 VERSION
 
-version 1.20161229
+version 1.20170115
 
 =head1 SYNOPSIS
 
@@ -117,10 +118,20 @@ Modern Perl and its implications, and
 L<http://onyxneon.com/books/modern_perl/index.html> for a freely-downloadable
 Modern Perl tutorial.
 
+=head2 Wrapping Modern::Perl
+
+If you want to wrap Modern::Perl in your own C<import()> method, you can do so
+to add additional pragmas or features, such as the use of L<Try::Tiny>. Please
+note that, if you do so, you will I<not> automatically enable C3 method
+resolution in the calling scope. This is due to how the L<mro> pragma works. In
+your custom C<import()> method, you will need to write code such as:
+
+    mro::set_mro( scalar caller(), 'c3' );
+
 =head2 Forward Compatibility
 
-For forward compatibility, I recommend you specify a I<year> as the single
-optional import tag. For example:
+For forward compatibility, I recommend you specify a string containing a
+I<year> value as the single optional import tag. For example:
 
     use Modern::Perl '2009';
     use Modern::Perl '2010';
@@ -149,6 +160,10 @@ optional import tag. For example:
 
     use Modern::Perl '2016';
 
+... enables 5.24 features, and:
+
+    use Modern::Perl '2017';
+
 ... enables 5.24 features.
 
 Obviously you cannot use newer features on earlier
@@ -202,15 +217,15 @@ Damian Conway (inspiration from L<Toolkit>), Florian Ragwitz
 (L<B::Hooks::Parser>, so I didn't have to write it myself), chocolateboy (for
 suggesting that I don't even need L<B::Hooks::Parser>), Damien Learns Perl,
 David Moreno, Evan Carroll, Elliot Shank, Andreas König, Father Chrysostomos,
-and Norbert E. Grüner for reporting bugs, filing patches, and requesting
-features.
+Gryphon Shafer, and Norbert E. Grüner for reporting bugs, filing patches, and
+requesting features.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2009-2016 chromatic, all rights reserved.
+Copyright 2009-2017 chromatic, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl 5.18 itself.
+under the same terms as Perl 5.24 itself.
 
 =head1 AUTHOR
 
